﻿using System.ComponentModel;
using Stimulsoft.Base;
using Stimulsoft.Base.Json.Linq;
using Stimulsoft.Base.Localization;
using Stimulsoft.Base.Serializing;
using Stimulsoft.Report.Dictionary;

namespace MyAssembly.NetCore;

public sealed class MySource : StiSqlSource
{
    #region Constructors

    public MySource()
    {
        Columns = new StiDataColumnsCollection(this);
        Parameters = new StiDataParametersCollection(this);
    }

    public MySource(string nameInSource, string name)
        : base(nameInSource, name)
    {
        Columns = new StiDataColumnsCollection(this);
        Parameters = new StiDataParametersCollection(this);
    }

    #endregion

    #region Properties

    [StiSerializable]
    [Description("Описание кастомного свойства MyCustomProperty")]
    [StiCategory("DataProcessing")]
    public bool MyCustomProperty { get; set; }

    [Browsable(false), StiSerializable]
    public new string NameInSource
    {
        get => base.NameInSource;
        set => base.NameInSource = value;
    }

    #endregion

    #region Save to Json

    public sealed override JObject SaveToJsonObject(StiJsonSaveMode mode)
    {
        var jObject = base.SaveToJsonObject(mode);

        var myObject = new JObject();
        myObject.AddPropertyBool(nameof(MyCustomProperty), MyCustomProperty);
        jObject.Add(new JProperty("MyGroup", myObject));
        return jObject;
    }

    #endregion

    public override StiDataParameter AddParameter() => throw new NotSupportedException();

    public override void Connect(StiDataCollection datas, bool loadData, bool invokeEvents = true)
    {
        var adapter = GetDataAdapter();
        adapter?.ConnectDataSourceToData(Dictionary, this, loadData);
    }

    protected override Type GetDataAdapterType() => typeof(MySource);
}
